/***************************************
  $Header: /home/amb/wwwoffle/RCS/sockets.h 2.9 2001/05/19 18:59:24 amb Exp $

  WWWOFFLE - World Wide Web Offline Explorer - Version 2.6d.
  Socket function header file.
  ******************/ /******************
  Written by Andrew M. Bishop

  This file Copyright 1996,97,98,99,2000,01 Andrew M. Bishop
  It may be distributed under the GNU Public License, version 2, or
  any higher version.  See section COPYING of the GNU Public license
  for conditions under which this file may be redistributed.
  ***************************************/


#ifndef SOCKETS_H
#define SOCKETS_H    /*+ To stop multiple inclusions. +*/

/* in sockets.c */

int OpenClientSocket(char* host, int port);

int OpenServerSocket(char* host,int port);
int AcceptConnect(int socket);

int SocketRemoteName(int socket,char **name,char **ipname,int *port);
int SocketLocalName(int socket,char **name,char **ipname,int *port);

int CloseSocket(int socket);
#ifdef __CYGWIN__
int CloseCygwinSocket(int socket);
#endif

char *GetFQDN(void);

void SetDNSTimeout(int timeout);
void SetConnectTimeout(int timeout);

#endif /* SOCKETS_H */
